<?php

namespace B2buy\CareProvider\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use B2buy\CareProvider\Http\Requests\CareProviderRequest;
use B2buy\CareProvider\Interfaces\CareProviderRepositoryInterface;
use B2buy\CareProvider\Models\CareProvider;

/**
 * Resource controller class for care_provider.
 */
class CareProviderResourceController extends BaseController
{

    /**
     * Initialize care_provider resource controller.
     *
     * @param type CareProviderRepositoryInterface $care_provider
     *
     * @return null
     */
    public function __construct(CareProviderRepositoryInterface $care_provider)
    {
        parent::__construct();
        $this->repository = $care_provider;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\B2buy\CareProvider\Repositories\Criteria\CareProviderResourceCriteria::class);
    }

    /**
     * Display a list of care_provider.
     *
     * @return Response
     */
    public function index(CareProviderRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\B2buy\CareProvider\Repositories\Presenter\CareProviderPresenter::class)
                ->$function();
        }

        $care_providers = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('care_provider::care_provider.names'))
            ->view('care_provider::care_provider.index', true)
            ->data(compact('care_providers', 'view'))
            ->output();
    }

    /**
     * Display care_provider.
     *
     * @param Request $request
     * @param Model   $care_provider
     *
     * @return Response
     */
    public function show(CareProviderRequest $request, CareProvider $care_provider)
    {

        if ($care_provider->exists) {
            $view = 'care_provider::care_provider.show';
        } else {
            $view = 'care_provider::care_provider.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('care_provider::care_provider.name'))
            ->data(compact('care_provider'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new care_provider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CareProviderRequest $request)
    {

        $care_provider = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('care_provider::care_provider.name')) 
            ->view('care_provider::care_provider.create', true) 
            ->data(compact('care_provider'))
            ->output();
    }

    /**
     * Create new care_provider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CareProviderRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $care_provider                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('care_provider::care_provider.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('care_provider/care_provider/' . $care_provider->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/care_provider/care_provider'))
                ->redirect();
        }

    }

    /**
     * Show care_provider for editing.
     *
     * @param Request $request
     * @param Model   $care_provider
     *
     * @return Response
     */
    public function edit(CareProviderRequest $request, CareProvider $care_provider)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('care_provider::care_provider.name'))
            ->view('care_provider::care_provider.edit', true)
            ->data(compact('care_provider'))
            ->output();
    }

    /**
     * Update the care_provider.
     *
     * @param Request $request
     * @param Model   $care_provider
     *
     * @return Response
     */
    public function update(CareProviderRequest $request, CareProvider $care_provider)
    {
        try {
            $attributes = $request->all();

            $care_provider->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('care_provider::care_provider.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('care_provider/care_provider/' . $care_provider->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('care_provider/care_provider/' . $care_provider->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the care_provider.
     *
     * @param Model   $care_provider
     *
     * @return Response
     */
    public function destroy(CareProviderRequest $request, CareProvider $care_provider)
    {
        try {

            $care_provider->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('care_provider::care_provider.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('care_provider/care_provider/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('care_provider/care_provider/' . $care_provider->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple care_provider.
     *
     * @param Model   $care_provider
     *
     * @return Response
     */
    public function delete(CareProviderRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('care_provider::care_provider.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('care_provider/care_provider'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/care_provider/care_provider'))
                ->redirect();
        }

    }

    /**
     * Restore deleted care_providers.
     *
     * @param Model   $care_provider
     *
     * @return Response
     */
    public function restore(CareProviderRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('care_provider::care_provider.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/care_provider/care_provider'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/care_provider/care_provider/'))
                ->redirect();
        }

    }

}
